#include "sdl4gcj/SDLException.h"

#include <gcj/cni.h>
#include <SDL.h>

using namespace sdl4gcj;

::java::lang::String *
SDLException::getError()
{
	JvInitClass(&sdl4gcj::SDLException::class$);
	return JvNewStringLatin1(SDL_GetError());
}
